@@ -173,6 +173,8 @@ class TalosProducer(object):
                                       + str(traceback.format_exc()))
 
         if not partitionId:
+            self.logger.debug("add_user_message without assign specific partition id for："
+                              + self.topicName)
             self.do_add_user_message(msgList)
         else:
             userMessageList = []
@@ -195,6 +197,7 @@ class TalosProducer(object):
         # check / update curPartitionId
         if self.should_update_partition():
             self.curPartitionId = (self.curPartitionId + 1) % self.partitionNumber
+            self.logger.debug("change cur partition id to: " + str(self.curPartitionId))
             self.lastUpdatePartitionIdTime = Utils.current_time_mills()
             self.lastAddMsgNumber = 0
         currentPartitionId = self.curPartitionId
@@ -302,6 +305,8 @@ class TalosProducer(object):
                                           self.messageCallbackExecutors,
                                           globalLock=self.globalLock, producer=self)
         self.partitionSenderMap[partitionId] = partitionSender
+        self.logger.debug("init partition sender for: " + self.topicName
+                          + "for partitionId : " + str(partitionId))
 
     @synchronized
     def release_partition_sender(self, partitionId=None):
@@ -322,7 +327,7 @@ class TalosProducer(object):
                                        + " not found")
 
         self.partitionNumber = response.topicAttribute.partitionNumber
-        self.curPartitionId = random.randint(0, self.partitionNumber)
+        self.curPartitionId = random.randint(0, self.partitionNumber-1)
         self.topicTalosResourceName = topicTalosResourceName
 
     def init_partition_sender(self):
